@@ -13,6 +13,10 @@ import (
 	"github.com/muesli/termenv"
 )
 
+const (
+	defaultLimit = 100
+)
+
 var (
 	focusedStyle = lipgloss.NewStyle().Foreground(lipgloss.Color("205"))
 	noStyle      = lipgloss.NewStyle()
@@ -29,6 +33,12 @@ type Model struct {
 	drivers []string
 	driver  string
 
+	// ssl connection params.
+	sslCertInput     textinput.Model
+	sslKeyInput      textinput.Model
+	sslPasswordInput textinput.Model
+	sslRootcertInput textinput.Model
+
 	// std data.
 	hostInput     textinput.Model
 	portInput     textinput.Model
@@ -39,8 +49,10 @@ type Model struct {
 	limitInput    textinput.Model
 
 	// ssl.
-	modes []string
-	ssl   string
+	postgreSQLSSLModes []string
+	mySQLSSLModes      []string
+	sqliteSSLModes     []string
+	sslMode            string
 }
 
 // Init initialize the meta-model.
@@ -64,7 +76,9 @@ func (m *Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	case 1:
 		return updateStd(msg, m)
 	case 2:
-		return updateSSL(msg, m)
+		return updateSSLMode(msg, m)
+	case 3:
+		return updateSSLConn(msg, m)
 	}
 
 	return m, tea.Quit
@@ -81,6 +95,8 @@ func (m *Model) View() string {
 		s = standardView(m)
 	case 2:
 		s = sslView(m)
+	case 3:
+		s = sslConnView(m)
 	}
 
 	return fmt.Sprint(s)
@@ -111,13 +127,33 @@ func (m *Model) Database() string {
 	return m.databaseInput.Value()
 }
 
-// SSL returns the ssl name value.
-func (m *Model) SSL() string {
-	return m.ssl
+// SSLMode returns the ssl mode name value.
+func (m *Model) SSLMode() string {
+	return m.sslMode
+}
+
+func (m *Model) SSLCert() string {
+	return m.sslCertInput.Value()
+}
+
+func (m *Model) SSLKey() string {
+	return m.sslKeyInput.Value()
+}
+
+func (m *Model) SSLPassword() string {
+	return m.sslPasswordInput.Value()
+}
+
+func (m *Model) SSLRootcert() string {
+	return m.sslRootcertInput.Value()
 }
 
 // Limit returns the limit input value from the user.
 func (m *Model) Limit() (uint, error) {
+	// if the user skipped the question, resort to default value
+	if m.limitInput.Value() == "" {
+		return defaultLimit, nil
+	}
 	limit, err := strconv.Atoi(m.limitInput.Value())
 	if err != nil {
 		return uint(0), err
@@ -182,19 +218,45 @@ func initModel() Model {
 	filePath.CharLimit = 1000
 	filePath.Focus()
 
+	sslCert := textinput.NewModel()
+	sslCert.Placeholder = "Client SSL certificate"
+	sslCert.CharLimit = 1000
+	sslCert.Focus()
+
+	sslKey := textinput.NewModel()
+	sslKey.Placeholder = "The location for the secret key used for the client certificate"
+	sslKey.CharLimit = 1000
+
+	sslPassword := textinput.NewModel()
+	sslPassword.Placeholder = "The password for the secret key"
+	sslPassword.CharLimit = 1000
+
+	sslRootCert := textinput.NewModel()
+	sslRootCert.Placeholder = "The name of a file containing SSL certificate authority (CA) certificate(s)"
+	sslRootCert.CharLimit = 1000
+
 	m := Model{
 		// the supported drivers by the client.
 		drivers: []string{"postgres", "mysql", "sqlite"},
 		// our default value.
 		driver: "postgres",
 
-		hostInput:     host,
-		portInput:     port,
-		userInput:     user,
-		passwordInput: password,
-		databaseInput: database,
-		limitInput:    limit,
-		filePathInput: filePath,
+		sslMode:            "disable",
+		postgreSQLSSLModes: []string{"disable", "require", "verify-full", "verify-ca"},
+		mySQLSSLModes:      []string{"true", "false", "skip-verify", "preferred"},
+		sqliteSSLModes:     []string{},
+
+		hostInput:        host,
+		portInput:        port,
+		userInput:        user,
+		passwordInput:    password,
+		databaseInput:    database,
+		limitInput:       limit,
+		filePathInput:    filePath,
+		sslCertInput:     sslCert,
+		sslKeyInput:      sslKey,
+		sslPasswordInput: sslPassword,
+		sslRootcertInput: sslRootCert,
 	}
 
 	return m
@@ -213,14 +275,18 @@ func Run() (command.Options, error) {
 	}
 
 	opts := command.Options{
-		Driver: m.driver,
-		Host:   m.Host(),
-		Port:   m.Port(),
-		User:   m.User(),
-		Pass:   m.Password(),
-		DBName: m.Database(),
-		SSL:    m.SSL(),
-		Limit:  limit,
+		Driver:      m.driver,
+		Host:        m.Host(),
+		Port:        m.Port(),
+		User:        m.User(),
+		Pass:        m.Password(),
+		DBName:      m.Database(),
+		SSL:         m.SSLMode(),
+		SSLCert:     m.SSLCert(),
+		SSLKey:      m.SSLKey(),
+		SSLPassword: m.SSLPassword(),
+		SSLRootcert: m.SSLRootcert(),
+		Limit:       limit,
 	}
 
 	if m.driver == "sqlite" {
@@ -232,5 +298,19 @@ func Run() (command.Options, error) {
 
 // IsEmpty checks if the given options objects is empty.
 func IsEmpty(opts command.Options) bool {
-	return cmp.Equal(opts, command.Options{}, cmpopts.IgnoreFields(command.Options{}, "SSL", "Limit"))
+	return cmp.Equal(
+		opts,
+		command.Options{},
+		cmpopts.IgnoreFields(
+			command.Options{},
+			"SSL",
+			"Limit",
+			"Socket",
+			"SSL",
+			"SSLCert",
+			"SSLKey",
+			"SSLPassword",
+			"SSLRootcert",
+		),
+	)
 }
