@@ -10,7 +10,7 @@ func driverView(m *Model) string {
 	// The header.
 	s := "Select the database driver:"
 	var choices string
-	// Iterate over the driver.
+	// Iterate over the drivers.
 	for i, driver := range m.drivers {
 		choices += fmt.Sprintf("%s\n", checkbox(driver, m.cursor == i))
 	}
@@ -57,24 +57,58 @@ func viewInputs(m *Model) []string {
 }
 
 func sslView(m *Model) string {
+	var sslModes []string
+
 	switch m.driver {
 	case drivers.Postgres:
-		m.modes = []string{"disable", "require", "verify-full"}
+		sslModes = m.postgreSQLSSLModes
 	case drivers.MySQL:
-		m.modes = []string{"true", "false", "skip-verify", "preferred"}
+		sslModes = m.mySQLSSLModes
 	case drivers.SQLite:
-		m.modes = []string{}
+		sslModes = m.sqliteSSLModes
 	default:
-		m.modes = []string{"disable", "require", "verify-full"}
+		sslModes = m.postgreSQLSSLModes
 	}
 
 	// The header.
 	s := "\nSelect the ssl mode (just press enter if you selected sqlite3):"
 	var choices string
 	// Iterate over the driver.
-	for i, mode := range m.modes {
+	for i, mode := range sslModes {
 		choices += fmt.Sprintf("%s\n", checkbox(mode, m.cursor == i))
 	}
 
 	return fmt.Sprintf("%s\n\n%s", s, choices)
 }
+
+func sslConnView(m *Model) string {
+	s := "Introduce the SSL connection params:\n\n"
+
+	inputs := sslConnViewInputs(m)
+
+	for i := 0; i < len(inputs); i++ {
+		s += inputs[i]
+		if i < len(inputs)-1 {
+			s += "\n"
+		}
+	}
+
+	s += "\n"
+
+	return s
+}
+
+func sslConnViewInputs(m *Model) []string {
+	var inputs []string
+
+	if m.driver == drivers.Postgres && (m.sslMode == "require" || m.sslMode == "verify-full" || m.sslMode == "verify-ca") {
+		inputs = []string{
+			m.sslCertInput.View(),
+			m.sslKeyInput.View(),
+			m.sslPasswordInput.View(),
+			m.sslRootcertInput.View(),
+		}
+	}
+
+	return inputs
+}
